# Get some variables provided by autosubmit.
# TODO: What do we do to ensure that these variables are defined in the proj file?
WORKDIR=%HPCROOTDIR%
ICON_VERSION=%ICON_VERSION%
SPACK_URL=%spack.url%
SPACK_BRANCH=%spack.branch%
SPACK_COMPILER=%spack.compiler%

# If the workdir directory does not exist create it
if [ ! -d ${WORKDIR} ]; then
  mkdir -p ${WORKDIR}
fi

# Go to the working directory
cd ${WORKDIR}

# Check if experiment's spack installation already exists, if it doesn't, clone it.
SPACK_ENV=spack/share/spack/setup-env.sh
if [ ! -f ${SPACK_ENV} ]; then
  git clone ${SPACK_URL} -b ${SPACK_BRANCH}
  #TODO: Would be good to enable the re-utilization of existing spack packages (via packages.yaml or upstreams.yaml)
fi

# Setup the environment
source ${SPACK_ENV}

# Use spack to get a recent enough version of python3
if [ $(
  spack find python@3.8: &>/dev/null
  echo $?
) -ne 0 ]; then
  echo "Installing a version of python3"
  # Compile openmpi with schedulers=slurm
  spack install python@3.8:
else
  echo "python@3.8: already installed!"
fi

# Link the python binary into the main folder so can be easily used later:

spack load python@3.8:

if [ ! -d venv ]; then
  # Create virtual environment
  python3 -m venv --prompt AS venv
fi

# Load environment
source venv/bin/activate

# Create a link to the binary
ln -sf $(which python3) ${WORKDIR}/python3

# Install enstools-compression via pip
# TODO: Due to a incompatibility issue between latest numba and numpy I have to add this here. Hopefully removable soon.
pip install numpy==1.23
pip install enstools-compression
