#!/bin/bash -l

# Get some variables provided by autosubmit.
WORKDIR=%HPCROOTDIR%
ICON_VERSION=%ICON_VERSION%

BGRID_GLOBAL=%simulation.BGRID_GLOBAL%
RGRID_GLOBAL=%simulation.RGRID_GLOBAL%
BGRID=%simulation.BGRID%
RGRID=%simulation.RGRID%
BEXTPAR=%simulation.BEXTPAR%

STARTDATE=%SDATE%

MEMBER=%MEMBER%

# Define rundir
RUNDIR=${WORKDIR}/${STARTDATE}/${MEMBER}

# Activate spack
SPACK_ENV=${WORKDIR}/spack/share/spack/setup-env.sh
source ${SPACK_ENV}

# Load icon module
spack load icon-nwp@%ICON_VERSION%

# Create member folder and go there
mkdir -p ${RUNDIR}

cd ${RUNDIR}

# Download or copy required input files
function download_file() {
  URL=$1
  FILE=${2:-$(basename $URL)}
  if [ ! -e $FILE ]; then
    echo "Download $URL => $FILE"
    wget -q $URL -O $FILE
  fi
}

# some settings
AN_MEMBER=$(printf "%03d" %initial_conditions.member%)
INITIAL_CONDITIONS_PARENT_FOLDER=%initial_conditions.parent_folder%

INITIAL_CONDITIONS_PATH=${INITIAL_CONDITIONS_PARENT_FOLDER}/${STARTDATE:0:6}/${STARTDATE:0:8}T00

AN_SOURCE=$(find ${INITIAL_CONDITIONS_PATH} -name "igaf*00.m${AN_MEMBER}.grb" | sort | tail -n 1)
FG_SOURCE=$(find ${INITIAL_CONDITIONS_PATH} -name igfff00030000.m${AN_MEMBER}.grb | sort | tail -n 1)

if [ ! -f "${AN_SOURCE}" ]; then
  echo "Analysis file for date ${STARTDATE} not found!"
  exit 1
fi

if [ ! -f "${FG_SOURCE}" ]; then
  echo "FG file for date ${STARTDATE} not found!"
  exit 1
fi

AN_FILE=$(basename ${AN_SOURCE})
FG_FILE=$(basename ${FG_SOURCE})

# Save filenames to be used later by other scripts.
echo ${AN_FILE} >an_file.txt
echo ${FG_FILE} >fg_file.txt

# Download grid files and external parameters
BASEURL=http://icon-downloads.mpimet.mpg.de/grids/public/edzw
download_file $BASEURL/$BGRID
download_file $BASEURL/$RGRID
download_file $BASEURL/$BEXTPAR

# Link first-guess and analysis files.
ln -sf ${FG_SOURCE} ${FG_FILE}
ln -sf ${AN_SOURCE} ${AN_FILE}

# Link input for radiation
ln -sf ${ICON_DATA_PATH}/rrtmg_lw.nc .
ln -sf ${ICON_DATA_PATH}/ECHAM6_CldOptProps.nc .
ln -sf ${ICON_BASE_PATH}/run/ana_varnames_map_file.txt .
